From 576b330ebd2541d89319ca4ef04e2fde172d2cc8 Mon Sep 17 00:00:00 2001
From: alecpl <alec@alec.pl>
Date: Wed, 24 Nov 2010 06:55:55 -0500
Subject: [PATCH] - Temporarily commented out \Noselect flag checking in select(), because of problems with Courier
---
program/include/rcube_message.php | 89 +++++++++++++++++++++++++++-----------------
1 files changed, 54 insertions(+), 35 deletions(-)
diff --git a/program/include/rcube_message.php b/program/include/rcube_message.php
index a40cdca..89d65eb 100644
--- a/program/include/rcube_message.php
+++ b/program/include/rcube_message.php
@@ -29,12 +29,23 @@
*/
class rcube_message
{
+ /**
+ * Instace of rcmail.
+ *
+ * @var rcmail
+ */
private $app;
+
+ /**
+ * Instance of imap class
+ *
+ * @var rcube_imap
+ */
private $imap;
private $opt = array();
private $inline_parts = array();
private $parse_alternative = false;
-
+
public $uid = null;
public $headers;
public $structure;
@@ -44,7 +55,7 @@
public $subject = '';
public $sender = null;
public $is_safe = false;
-
+
/**
* __construct
@@ -63,6 +74,7 @@
{
$this->app = rcmail::get_instance();
$this->imap = $this->app->imap;
+ $this->imap->get_all_headers = true;
$this->uid = $uid;
$this->headers = $this->imap->get_headers($uid, NULL, true, true);
@@ -93,26 +105,30 @@
// notify plugins and let them analyze this structured message object
$this->app->plugins->exec_hook('message_load', array('object' => $this));
}
-
-
+
+
/**
* Return a (decoded) message header
*
- * @param string Header name
- * @param bool Don't mime-decode the value
+ * @param string $name Header name
+ * @param bool $row Don't mime-decode the value
* @return string Header value
*/
public function get_header($name, $raw = false)
{
- $value = $this->headers->$name;
+ if ($this->headers->$name)
+ $value = $this->headers->$name;
+ else if ($this->headers->others[$name])
+ $value = $this->headers->others[$name];
+
return $raw ? $value : $this->imap->decode_header($value);
}
-
+
/**
* Set is_safe var and session data
*
- * @param bool enable/disable
+ * @param bool $safe enable/disable
*/
public function set_safe($safe = true)
{
@@ -124,7 +140,7 @@
/**
* Compose a valid URL for getting a message part
*
- * @param string Part MIME-ID
+ * @param string $mime_id Part MIME-ID
* @return string URL or false if part does not exist
*/
public function get_part_url($mime_id)
@@ -139,8 +155,8 @@
/**
* Get content of a specific part of this message
*
- * @param string Part MIME-ID
- * @param resource File pointer to save the message part
+ * @param string $mime_id Part MIME-ID
+ * @param resource $fp File pointer to save the message part
* @return string Part content
*/
public function get_part_content($mime_id, $fp=NULL)
@@ -198,27 +214,21 @@
/**
* Return the first text part of this message
*
+ * @param rcube_message_part $part Reference to the part if found
* @return string Plain text message/part content
*/
- function first_text_part()
+ function first_text_part(&$part=null)
{
// no message structure, return complete body
if (empty($this->parts))
return $this->body;
-
- $out = null;
// check all message parts
foreach ($this->mime_parts as $mime_id => $part) {
$mimetype = $part->ctype_primary . '/' . $part->ctype_secondary;
if ($mimetype == 'text/plain') {
- $out = $this->imap->get_message_part($this->uid, $mime_id, $part);
-
- // re-format format=flowed content
- if ($part->ctype_secondary == 'plain' && $part->ctype_parameters['format'] == 'flowed')
- $out = self::unfold_flowed($out);
- break;
+ return $this->imap->get_message_part($this->uid, $mime_id, $part);
}
else if ($mimetype == 'text/html') {
$out = $this->imap->get_message_part($this->uid, $mime_id, $part);
@@ -229,11 +239,12 @@
// create instance of html2text class
$txt = new html2text($out);
- $out = $txt->get_text();
+ return $txt->get_text();
}
}
- return $out;
+ $part = null;
+ return null;
}
@@ -241,8 +252,8 @@
* Raad the message structure returend by the IMAP server
* and build flat lists of content parts and attachments
*
- * @param object rcube_message_part Message structure node
- * @param bool True when called recursively
+ * @param rcube_message_part $structure Message structure node
+ * @param bool $recursive True when called recursively
*/
private function parse_structure($structure, $recursive = false)
{
@@ -388,9 +399,9 @@
if ($part_orig_mimetype == 'message/rfc822' && !empty($mail_part->filename))
$this->attachments[] = $mail_part;
}
- // part text/[plain|html] OR message/delivery-status
+ // part text/[plain|html] or delivery status
else if ((($part_mimetype == 'text/plain' || $part_mimetype == 'text/html') && $mail_part->disposition != 'attachment') ||
- $part_mimetype == 'message/delivery-status' || $part_mimetype == 'message/disposition-notification'
+ in_array($part_mimetype, array('message/delivery-status', 'text/rfc822-headers', 'message/disposition-notification'))
) {
// Allow plugins to handle also this part
$plugin = $this->app->plugins->exec_hook('message_part_structure',
@@ -437,7 +448,9 @@
}
// part is a file/attachment
else if (preg_match('/^(inline|attach)/', $mail_part->disposition) ||
- $mail_part->headers['content-id'] || (empty($mail_part->disposition) && $mail_part->filename)
+ $mail_part->headers['content-id'] ||
+ ($mail_part->filename &&
+ (empty($mail_part->disposition) || preg_match('/^[a-z0-9!#$&.+^_-]+$/i', $mail_part->disposition)))
) {
// skip apple resource forks
if ($message_ctype_secondary == 'appledouble' && $secondary_type == 'applefile')
@@ -457,8 +470,8 @@
else if ($part_orig_mimetype == 'message/rfc822') {
$this->parse_structure($mail_part, true);
}
- // is a regular attachment
- else if (preg_match('!^[a-z0-9-.+]+/[a-z0-9-.+]+$!i', $part_mimetype)) {
+ // is a regular attachment (content-type name regexp according to RFC4288.4.2)
+ else if (preg_match('/^[a-z0-9!#$&.+^_-]+\/[a-z0-9!#$&.+^_-]+$/i', $part_mimetype)) {
if (!$mail_part->filename)
$mail_part->filename = 'Part '.$mail_part->mime_id;
$this->attachments[] = $mail_part;
@@ -501,7 +514,7 @@
/**
* Fill aflat array with references to all parts, indexed by part numbers
*
- * @param object rcube_message_part Message body structure
+ * @param rcube_message_part $part Message body structure
*/
private function get_mime_numbers(&$part)
{
@@ -517,7 +530,8 @@
/**
* Decode a Microsoft Outlook TNEF part (winmail.dat)
*
* @param object rcube_message_part Message part to decode
*/
function tnef_decode(&$part)
{
@@ -552,7 +566,8 @@
/**
* Parse message body for UUencoded attachments bodies
*
* @param object rcube_message_part Message part to decode
*/
function uu_decode(&$part)
{
@@ -598,7 +613,7 @@
/**
* Interpret a format=flowed message body according to RFC 2646
*
- * @param string Raw body formatted as flowed text
+ * @param string $text Raw body formatted as flowed text
* @return string Interpreted text with unwrapped lines and stuffed space removed
*/
public static function unfold_flowed($text)
@@ -654,6 +669,10 @@
/**
* Wrap the given text to comply with RFC 2646
+ *
+ * @param string $text Text to wrap
+ * @param int $length Length
+ * @return string Wrapped text
*/
public static function format_flowed($text, $length = 72)
{
@@ -667,7 +686,7 @@
$line = rtrim(substr($line, $level));
$line = $prefix . rc_wordwrap($line, $length - $level - 2, " \r\n$prefix ");
}
- else {
+ else if ($line) {
$line = ' ' . rc_wordwrap(rtrim($line), $length - 2, " \r\n ");
}
@@ -517,7 +530,8 @@
* Decode a Microsoft Outlook TNEF part (winmail.dat)
*
- * @param object rcube_message_part Message part to decode
+ * @param rcube_message_part $part Message part to decode
+ * @return array
*/
function tnef_decode(&$part)
@@ -552,7 +566,8 @@
* Parse message body for UUencoded attachments bodies
*
- * @param object rcube_message_part Message part to decode
+ * @param rcube_message_part $part Message part to decode
+ * @return array
*/
function uu_decode(&$part)
--
Gitblit v1.9.1